# pyfsdb viewer

This package is a [textual] display interface for visually showing the
contents of an [pyfsdb] table of data.

[textual]: https://pypi.org/project/textual/
[pyfsdb]: https://fsdb.readthedocs.io/
